# Welcome to Alpha environment documention

Alpha is an **ecosystem** based on multiple **frameworks** and **libraries** for both **frontend** and **backend**.

## Backend: Alphaz

- Alphaz is a backend toolbox/framework based on a combination between Flask, SqlAlchemy and a multitude of other libraries.

    !!! note
        The overriding goal for Alphaz is to ease the backend development and easely link python backend to Angular frontend [Alphaa].

## Features

-   API Routing parameters management upgrade
-   Enhanced json files configuration

## Tech

Alphaz uses a number of open source projects to work properly:

-   [Flask](https://flask.palletsprojects.com/en/1.1.x/) - a micro web framework
-   [SqlAlchemy](https://www.sqlalchemy.org/) - a database toolkit
-   [Flask-SqlAlchemy](https://flask-sqlalchemy.palletsprojects.com/en/2.x/) - an extension for Flask that adds support for SQLAlchemy

## Project layout

- How to setup `Alpha`: [Alpha](alpha_setup.md)
## Frontend: Alphaa

- Alphaa is a frontend toolbox/framework

    !!! note
        The overriding goal for Alphaa is to ease the frontend development and easely link Angular frontend to python backend [Alphaz].
## Features

- Enhanced services
- Master class


## Project layout

- How to setup `Alpha`: [Alpha](alpha_setup.md)